#!/bin/bash
# ************************************************
# Copyright (c) 2020 FXDaemon All Rights Reserved.
# ************************************************

module=fxTrade
mail_to=

home_path=$(cd $(dirname $0);pwd)
source ${home_path}/setenv.sh

# demo and virtual user
ini_files=()
ini_files+=( "fxTrade-demo.ini" )          # 4:00 start
ini_files+=( "fxTrade-virtual.ini" )       # 4:10 start

dateStr=`date "+%Y %m %d %H %M %w %s"`
year=`echo $dateStr | cut -d" " -f 1`
month=`echo $dateStr | cut -d" " -f 2`
day=`echo $dateStr | cut -d" " -f 3`
hour=`echo $dateStr | cut -d" " -f 4`
minute=`echo $dateStr | cut -d" " -f 5`
week=`echo $dateStr | cut -d" " -f 6`
time=`echo $dateStr | cut -d" " -f 7`
today="${year}-${month}-${day}"

# $1:to $2:subject stdin:content
sendMail()
{
  (
    echo "From: fxtrade-sh"
    echo "To: $1"
    echo "Subject: $2"
    cat
  ) | /usr/sbin/sendmail -t
}

# Saturday
if [ $week -eq 6 -a $hour -ge 7 ]; then
  closeTime=`date -d "${today} 8:00:00" '+%s'`
  if [ $time -gt $closeTime ]; then
    for (( i=0; i<${#ini_files[@]}; ++i ))
    do
      pid=`ps aux | grep -v grep | grep ${module} | grep ${ini_files[$i]} | awk '{print $2}'`
      if [ -n "$pid" ]; then
        kill -9 $pid
      fi
    done
  fi
  exit
fi

# New year's day
if [ $month -eq 1 -a $day -eq 1 ]; then
  exit
fi

# $1:ini_file
startTrade () 
{
  ini_file=$1
  pid=`ps -ef | grep -v grep | grep ${module} | grep ${ini_file} | awk '{ print $2 }'`
  if [ -z "$pid" ]; then
    if [ -n "$mail_to" ]; then
      echo ${dateStr} | sendMail $mail_to "${ini_file} start"
    fi
    exec ${module} -s --ini=${ini_file} > /dev/null 2>&1 &
    echo `date +"%Y/%m/%d %H:%M:%S"` > ${home_path}/tmp/${ini_file}.servertime
  else
    agoTime=`date -d '1 hours ago' '+%s'`
    serverTimeStr=`cat "${home_path}/tmp/${ini_file}.servertime"`
    if [ -z "$serverTimeStr" ]; then
      serverTime=`date '+%s'`
    else
      serverTime=`date -d "$serverTimeStr" '+%s'`
    fi
    if [ $serverTime -lt $agoTime ]; then
      kill -3 $pid
      sleep 60
      pid=`ps -ef | grep -v grep | grep ${module} | grep ${ini_file} | awk '{ print $2 }'`
      if [ -n "$pid" ]; then
        kill -9 $pid
      fi
    fi
  fi
}

# Monday
if [ $week -eq 1 ]; then
  startTime1=`date -d "${today} 4:00:00" '+%s'`
  startTime2=`date -d "${today} 4:10:00" '+%s'`
  startTime3=`date -d "${today} 4:20:00" '+%s'`
  if [ $time -lt $startTime1 ]; then
    exit
  elif [ $time -ge $startTime1 -a $time -lt $startTime2 ]; then
    startTrade ${ini_files[0]}
    exit
  elif [ $time -ge $startTime2 -a $time -lt $startTime3 ]; then
    startTrade ${ini_files[1]}
    exit
  fi
fi

for (( i=0; i<${#ini_files[@]}; ++i ))
do
  startTrade ${ini_files[$i]}
done
